@@ -10,6 +10,7 @@
 
 #include <KLocalizedString>
 #include <KPluginMetaData>
+#include <KSharedConfig>
 
 #include "pluginactivity.h"
 #include <interfaces/guiinterface.h>
@@ -38,7 +39,7 @@ PluginManager::~PluginManager()
 
 void PluginManager::loadPluginList()
 {
-    pluginsMetaData = KPluginLoader::findPlugins(QStringLiteral("ktorrent"));
+    pluginsMetaData = KPluginMetaData::findPlugins(QStringLiteral("ktorrent_plugins"));
 
     if (!prefpage) {
         prefpage = new PluginActivity(this);
@@ -50,19 +51,16 @@ void PluginManager::loadPluginList()
     prefpage->update();
 }
 
-inline bool isPluginEnabled(const KPluginMetaData &data)
-{
-    return KSharedConfig::openConfig()->group(data.pluginId()).readEntry(data.pluginId() + QLatin1String("Enabled"), data.isEnabledByDefault());
-}
 
 void PluginManager::loadPlugins()
 {
+    const KConfigGroup cfg = KSharedConfig::openConfig()->group("Plugins");
     int idx = 0;
     for (const KPluginMetaData &data : qAsConst(pluginsMetaData)) {
-        if (loaded.contains(idx) && !isPluginEnabled(data)) {
+        if (loaded.contains(idx) && !data.isEnabled(cfg)) {
             // unload it
             unload(data, idx);
-        } else if (!loaded.contains(idx) && isPluginEnabled(data)) {
+        } else if (!loaded.contains(idx) && data.isEnabled(cfg)) {
             // load it
             load(data, idx);
         }
@@ -72,13 +70,7 @@ void PluginManager::loadPlugins()
 
 void PluginManager::load(const KPluginMetaData &data, int idx)
 {
-    KPluginLoader loader(data.fileName());
-    KPluginFactory *factory = loader.factory();
-    if (!factory)
-        return;
-
-    factory->setMetaData(data);
-    Plugin *plugin = factory->create<kt::Plugin>();
+    auto plugin = KPluginFactory::instantiatePlugin<kt::Plugin>(data).plugin;
     if (!plugin) {
         Out(SYS_GEN | LOG_NOTICE) << QStringLiteral("Creating instance of plugin %1 failed !").arg(pluginsMetaData.at(idx).fileName()) << endl;
         return;
