@@ -25,7 +25,7 @@ ScanFolderPrefPage::ScanFolderPrefPage(ScanFolderPlugin *plugin, QWidget *parent
     connect(m_add, &QPushButton::clicked, this, &ScanFolderPrefPage::addPressed);
     connect(m_remove, &QPushButton::clicked, this, &ScanFolderPrefPage::removePressed);
     connect(m_folders, &QListWidget::itemSelectionChanged, this, &ScanFolderPrefPage::selectionChanged);
-    connect(m_group, qOverload<int>(&QComboBox::currentIndexChanged), this, &ScanFolderPrefPage::currentGroupChanged);
+    connect(m_group, &QComboBox::currentIndexChanged, this, &ScanFolderPrefPage::currentGroupChanged);
 }
 
 ScanFolderPrefPage::~ScanFolderPrefPage()
